Crate interface

Crate interface 

Structs

Blob
BlobInfo
BlobInfoRequest
BlobMeta
Metadata associated with a blob.
BlobMetaRequest
Metadata accepted when indexing a blob.
CertificateInfo
FacetResponse
Hit
MetadataList
MoveInformation
Query
A query that can be sent to a Menmos cluster.
QueryResponse
The results of a query.
RoutingConfig
RoutingConfigState
StorageNodeInfo
StorageNodeResponseData
Data sent back to the storage node from the directory.
TaggedBlobInfo
TaggedBlobMeta
Tagged version of the metadata associated with a blob.
TaggedRoutingConfig
TaggedRoutingConfigState

Enums

DirtyState
Expression
ExpressionField
FieldValue
RedirectInfo
RoutingAlgorithm
SortOrder
A sorting order.
TaggedFieldValue

Traits

BlobIndexer
DirectoryNode
NodeAdminController
QueryExecutor
RoutingConfigManager
StorageNode
UserManagement

Type Aliases

DynDirectoryNode
DynStorageNode