Crate interface[−][src]
Structs
| Blob | |
| BlobInfo | |
| BlobMeta | Metadata associated with a blob. |
| CertificateInfo | |
| FacetResponse | |
| Hit | |
| MetadataList | |
| Query | A query that can be sent to a Menmos cluster. |
| QueryResponse | The results of a query. |
| StorageNodeInfo | |
| StorageNodeResponseData | Data sent back to the storage node from the directory. |
Enums
| Expression | A parsed (or manually constructed) query expression. |
| RedirectInfo | |
| Type | The type of a blob in a menmos cluster (file or directory). |
Traits
| DirectoryNode | |
| StorageNode |